#!/usr/bin/perl
use strict;
# ---------------------------------------------------------------------------- #
# mqCertRpt.pl
#
# Script to print out the certificates and expiration dates from a cluster 
# of QMgrs
# ---------------------------------------------------------------------------- #

# Make sure that SupportPac MO72 'mqsc' command is in the PATH.  In this case 
# it's in . but best to put it in /opt/mqm/bin and leave $ENV{PATH} alone.
$ENV{PATH} = "$ENV{PATH}:.";

# Shell one-liner that fetches a local QMgr name. If there's more than one it gets the first one reported.
my $QMgr = `dspmq 2>&1| grep -i '(Running)' | tr ')' '\n' | grep QMNAME | tr '(' '\n' | grep -v QMNAME | head -1`;

if ($QMgr) {        # Did we find one?
    chomp $QMgr;
    print "Found '$QMgr' local queue manager\nStarting certificate report on local cluster.\n\n";

    # Now go get the list of QMgrs in the cluster.  This is intended to be run from the repository QMgr.
    # Uses the mqsc executable from SupportPac MO72 that prints output on one line per object.
    foreach (`echo 'dis clusqmgr(*) cluster(*) CONNAME' | ./mqsc -m $QMgr -p wrap=no | grep CLUSQMGR`) {
        
        # Grab the QMgr name and the CONNAME from the mqsc output. Leave out any trailing ) chars.
        my ($thisQMgr, $thisCONNAME) = /CLUSQMGR\((\S+?)\) .* CONNAME\((\S+?)\)/;
        
        # We need to convert the CONNAME to host:port for openssl.
        if ($thisCONNAME =~ /\(/) {
            # If the CONNAME has a ( then convert to : and keep the port
            $thisCONNAME =~ s/\(/:/;
        } else {
            # Otherwise add the default port.
            $thisCONNAME .= ":1414";
        }
        
        # Print the QMgr name and the CONNAME, then run the openssl commands
        print "$thisQMgr Queue Manager hosted at $thisCONNAME\n";
        # Make sure to have a private key to send which will _NOT_ be known to the QMgr
        # or else openssl will hang and the QMgr will cut an fdC file.
        print `openssl s_client -connect $thisCONNAME -cert key.pem -prexit 2>&1 | openssl x509 -enddate -issuer -subject -noout`, "\n\n";
        
    }
} else {
    # Could not find a QMgr. Print output of dspmq for diagnostic.
    print "ERROR: No local running QMgr found.\n\n"; 
    print `dspmq 2>&1`;
}


